@@ -2,7 +2,8 @@ from __future__ import annotations
 
 import argparse
 import logging
-from typing import Any, List, Optional
+from collections import Counter
+from typing import Any, Optional
 
 import pandas
 import requests
@@ -10,7 +11,7 @@ from annofabapi.models import Comment, CommentType
 
 import annofabcli
 import annofabcli.common.cli
-from annofabcli.common.cli import AbstractCommandLineInterface, ArgumentParser, build_annofabapi_resource_and_login
+from annofabcli.common.cli import ArgumentParser, CommandLine, build_annofabapi_resource_and_login
 from annofabcli.common.enums import FormatArgument
 from annofabcli.common.facade import AnnofabApiFacade
 from annofabcli.common.utils import print_according_to_format, print_csv
@@ -19,15 +20,49 @@ from annofabcli.common.visualize import AddProps
 logger = logging.getLogger(__name__)
 
 
-class ListingComments(AbstractCommandLineInterface):
-    def get_comments(self, project_id: str, task_id: str, input_data_id: str):
+def create_reply_counter(comments: list[dict[str, Any]]) -> Counter[tuple[str, str, str]]:
+    """
+    返信コメントの回数を取得するcounterを生成します。
+
+    """
+    root_comment_id_counter = Counter((c["task_id"], c["input_data_id"], c["comment_node"]["root_comment_id"]) for c in comments if c["comment_node"]["_type"] == "Reply")
+    return root_comment_id_counter
+
+
+def create_empty_df_comment() -> pandas.DataFrame:
+    return pandas.DataFrame(
+        columns=[
+            "project_id",
+            "task_id",
+            "input_data_id",
+            "comment_id",
+            "phase",
+            "phase_stage",
+            "comment_type",
+            "account_id",
+            "user_id",
+            "username",
+            "phrases",
+            "comment",
+            "created_datetime",
+            "updated_datetime",
+            "reply_count",
+        ]
+    )
+
+
+class ListingComments(CommandLine):
+    def get_comments(self, project_id: str, task_id: str, input_data_id: str) -> list[dict[str, Any]]:
         comments, _ = self.service.api.get_comments(project_id, task_id, input_data_id, query_params={"v": "2"})
+        # 返信回数を算出する
+        reply_counter = create_reply_counter(comments)
+        for c in comments:
+            key = (c["task_id"], c["input_data_id"], c["comment_id"])
+            c["reply_count"] = reply_counter.get(key, 0)
         return comments
 
-    def get_comment_list(
-        self, project_id: str, task_id_list: List[str], *, comment_type: Optional[CommentType], exclude_reply: bool
-    ) -> list[dict[str, Any]]:
-        all_comments: List[Comment] = []
+    def get_comment_list(self, project_id: str, task_id_list: list[str], *, comment_type: Optional[CommentType], exclude_reply: bool) -> list[dict[str, Any]]:
+        all_comments: list[Comment] = []
 
         for task_id in task_id_list:
             try:
@@ -51,54 +86,53 @@ class ListingComments(AbstractCommandLineInterface):
                     all_comments.extend(comments)
 
             except requests.HTTPError:
-                logger.warning(f"タスク task_id = {task_id} のコメントを取得できませんでした。", exc_info=True)
+                logger.warning(f"task_id='{task_id}'のタスクのコメントの取得に失敗しました。", exc_info=True)
 
         visualize = AddProps(self.service, project_id)
         all_comments = [visualize.add_properties_to_comment(e) for e in all_comments]
+
         return all_comments
 
-    def main(self):
+    def main(self) -> None:
         args = self.args
         task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id)
         comment_type = CommentType(args.comment_type) if args.comment_type is not None else None
 
-        comment_list = self.get_comment_list(
-            args.project_id, task_id_list, comment_type=comment_type, exclude_reply=args.exclude_reply
-        )
+        comment_list = self.get_comment_list(args.project_id, task_id_list, comment_type=comment_type, exclude_reply=args.exclude_reply)
 
         logger.info(f"コメントの件数: {len(comment_list)}")
 
         output_format = FormatArgument(args.format)
         if output_format == FormatArgument.CSV:
-            df = pandas.json_normalize(comment_list)
+            if len(comment_list) > 0:
+                df = pandas.json_normalize(comment_list)
+            else:
+                df = create_empty_df_comment()
+
             print_csv(df, output=args.output)
         else:
             print_according_to_format(comment_list, output_format, output=args.output)
 
 
-def main(args: argparse.Namespace):
+def main(args: argparse.Namespace) -> None:
     service = build_annofabapi_resource_and_login(args)
     facade = AnnofabApiFacade(service)
     ListingComments(service, facade, args).main()
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser) -> None:
     argument_parser = ArgumentParser(parser)
 
     argument_parser.add_project_id()
     argument_parser.add_task_id(
         required=True,
-        help_message="対象のタスクのtask_idを指定します。" " ``file://`` を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。",
+        help_message="対象のタスクのtask_idを指定します。 ``file://`` を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。",
     )
 
     parser.add_argument(
         "--comment_type",
         choices=[CommentType.INSPECTION.value, CommentType.ONHOLD.value],
-        help=(
-            "コメントの種類で絞り込みます。\n\n"
-            f" * {CommentType.INSPECTION.value}: 検査コメント\n"
-            f" * {CommentType.ONHOLD.value}: 保留コメント\n"
-        ),
+        help=(f"コメントの種類で絞り込みます。\n\n * {CommentType.INSPECTION.value}: 検査コメント\n * {CommentType.ONHOLD.value}: 保留コメント\n"),
     )
 
     parser.add_argument("--exclude_reply", action="store_true", help="返信コメントを除外します。")
@@ -113,12 +147,11 @@ def parse_args(parser: argparse.ArgumentParser):
         default=FormatArgument.CSV,
     )
     argument_parser.add_output()
-    argument_parser.add_csv_format()
 
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "list"
     subcommand_help = "コメント一覧を出力します。"
 
