@@ -14,7 +14,7 @@ from datauri import DataURI
 from PIL import Image
 
 import annofabcli
-from annofabcli.common.cli import AbstractCommandLineInterface, ArgumentParser, build_annofabapi_resource_and_login
+from annofabcli.common.cli import ArgumentParser, CommandLine, build_annofabapi_resource_and_login
 from annofabcli.common.facade import AnnofabApiFacade
 
 logger = logging.getLogger(__name__)
@@ -31,7 +31,10 @@ def save_image_from_data_uri_scheme(value: str, temp_dir: Path) -> Path:
         Path: 保存した画像パス
     """
     uri = DataURI(value)
-    extension = uri.mimetype.split("/")[1]
+    mimetype = uri.mimetype
+    assert mimetype is not None
+    # "image/png"というmimetypeから"png"を取り出して、それをファイルの拡張子とする
+    extension = mimetype.split("/")[1]
 
     md5_hash = hashlib.md5(uri.data).hexdigest()
     image_file_name = f"{md5_hash}.{extension}"
@@ -39,16 +42,16 @@ def save_image_from_data_uri_scheme(value: str, temp_dir: Path) -> Path:
     with Image.open(io.BytesIO(uri.data)) as img:
         image_file_path = temp_dir / image_file_name
         img.save(str(image_file_path), extension.upper())
-        logger.debug(f"Data URI Schemeの画像を {str(image_file_path)} に保存しました。")
+        logger.debug(f"Data URI Schemeの画像を {image_file_path!s} に保存しました。")
         return image_file_path
 
 
-class UploadInstruction(AbstractCommandLineInterface):
+class UploadInstruction(CommandLine):
     """
     作業ガイドをアップロードする
     """
 
-    def upload_html_to_instruction(self, project_id: str, html_path: Path, temp_dir: Path):
+    def upload_html_to_instruction(self, project_id: str, html_path: Path, temp_dir: Path) -> None:  # noqa: PLR0912
         with html_path.open(encoding="utf-8") as f:
             file_content = f.read()
         pq_html = pyquery.PyQuery(file_content)
@@ -57,7 +60,7 @@ class UploadInstruction(AbstractCommandLineInterface):
         img_path_dict: dict[str, str] = {}
         # 画像をすべてアップロードして、img要素のsrc属性値を annofab urlに変更する
         for img_elm in pq_img:
-            src_value: str = img_elm.attrib.get("src")
+            src_value: Optional[str] = img_elm.attrib.get("src")
             if src_value is None:
                 continue
 
@@ -66,7 +69,7 @@ class UploadInstruction(AbstractCommandLineInterface):
 
             if src_value.startswith("data:"):
                 img_path = save_image_from_data_uri_scheme(src_value, temp_dir=temp_dir)
-            else:
+            else:  # noqa: PLR5501
                 if src_value[0] == "/":
                     img_path = Path(src_value)
                 else:
@@ -103,7 +106,7 @@ class UploadInstruction(AbstractCommandLineInterface):
         self.update_instruction(project_id, html_data)
         logger.info("作業ガイドを更新しました。")
 
-    def update_instruction(self, project_id: str, html_data: str):
+    def update_instruction(self, project_id: str, html_data: str) -> None:
         histories, _ = self.service.api.get_instruction_history(project_id)
         if len(histories) > 0:
             last_updated_datetime = histories[0]["updated_datetime"]
@@ -113,37 +116,38 @@ class UploadInstruction(AbstractCommandLineInterface):
         request_body = {"html": html_data, "last_updated_datetime": last_updated_datetime}
         self.service.api.put_instruction(project_id, request_body=request_body)
 
-    def main(self):
+    def main(self) -> None:
         args = self.args
 
         with tempfile.TemporaryDirectory() as str_temp_dir:
             self.upload_html_to_instruction(args.project_id, Path(args.html), temp_dir=Path(str_temp_dir))
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     service = build_annofabapi_resource_and_login(args)
     facade = AnnofabApiFacade(service)
     UploadInstruction(service, facade, args).main()
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser) -> None:
     argument_parser = ArgumentParser(parser)
 
     argument_parser.add_project_id()
 
     parser.add_argument(
-        "--html", type=str, required=True, help="作業ガイドとして登録するHTMLファイルのパスを指定します。body要素があればbody要素の中身をアップロードします。"
+        "--html",
+        type=str,
+        required=True,
+        help="作業ガイドとして登録するHTMLファイルのパスを指定します。body要素があればbody要素の中身をアップロードします。",
     )
 
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "upload"
     subcommand_help = "HTMLファイルを作業ガイドとして登録します。"
-    description = (
-        "HTMLファイルを作業ガイドとして登録します。" + "img要素のsrc属性がローカルの画像を参照している場合（http, https, dataスキーマが付与されていない）、" "画像もアップロードします。"
-    )
+    description = "HTMLファイルを作業ガイドとして登録します。img要素のsrc属性がローカルの画像を参照している場合（http, https, dataスキーマが付与されていない）、画像もアップロードします。"
     epilog = "チェッカーまたはオーナロールを持つユーザで実行してください。"
     parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description, epilog=epilog)
     parse_args(parser)
