@@ -1,7 +1,8 @@
 import argparse
 import logging
 import sys
-from typing import Any, Dict, List, Optional
+from collections.abc import Collection
+from typing import Any, Optional
 
 import requests
 from annofabapi.models import ProjectMember, ProjectMemberRole, ProjectMemberStatus
@@ -9,8 +10,8 @@ from annofabapi.models import ProjectMember, ProjectMemberRole, ProjectMemberSta
 import annofabcli
 from annofabcli.common.cli import (
     COMMAND_LINE_ERROR_STATUS_CODE,
-    AbstractCommandLineInterface,
     ArgumentParser,
+    CommandLine,
     build_annofabapi_resource_and_login,
 )
 from annofabcli.common.facade import AnnofabApiFacade
@@ -19,7 +20,7 @@ from annofabcli.project_member.put_project_members import PutProjectMembers
 logger = logging.getLogger(__name__)
 
 
-class ChangeProjectMembers(AbstractCommandLineInterface):
+class ChangeProjectMembers(CommandLine):
     """
     プロジェクトメンバのメンバ情報を更新する。
     """
@@ -30,7 +31,7 @@ class ChangeProjectMembers(AbstractCommandLineInterface):
         user_id: str,
         old_member: ProjectMember,
         member_role: Optional[ProjectMemberRole] = None,
-        member_info: Optional[Dict[str, Any]] = None,
+        member_info: Optional[dict[str, Any]] = None,
     ) -> ProjectMember:
         """
         1人のプロジェクトメンバを変更する。
@@ -46,7 +47,7 @@ class ChangeProjectMembers(AbstractCommandLineInterface):
 
         """
 
-        def get_value(key):
+        def get_value(key: str):  # noqa: ANN202
             if member_info is None:
                 return old_member[key]
 
@@ -68,12 +69,12 @@ class ChangeProjectMembers(AbstractCommandLineInterface):
         updated_project_member = self.service.api.put_project_member(project_id, user_id, request_body=request_body)[0]
         return updated_project_member
 
-    def change_project_members(
+    def change_project_members(  # noqa: ANN201
         self,
         project_id: str,
-        user_id_list,
+        user_id_list: Collection[str],
         member_role: Optional[ProjectMemberRole] = None,
-        member_info: Optional[Dict[str, Any]] = None,
+        member_info: Optional[dict[str, Any]] = None,
     ):
         """
         プロジェクトメンバのメンバ情報を更新する。
@@ -110,45 +111,40 @@ class ChangeProjectMembers(AbstractCommandLineInterface):
 
             # メンバを登録
             try:
-                self.put_project_member(
-                    project_id, user_id, old_member, member_role=member_role, member_info=member_info
-                )
-                logger.debug(
-                    f"user_id = {user_id} のプロジェクトメンバ情報を変更しました。member_role={member_role}, member_info={member_info}"
-                )
+                self.put_project_member(project_id, user_id, old_member, member_role=member_role, member_info=member_info)
+                logger.debug(f"user_id = {user_id} のプロジェクトメンバ情報を変更しました。member_role={member_role}, member_info={member_info}")
                 count_invite_members += 1
 
-            except requests.exceptions.HTTPError as e:
-                logger.warning(e)
-                logger.warning(f"プロジェクトメンバの登録に失敗しました。user_id={user_id}")
+            except requests.exceptions.HTTPError:
+                logger.warning(f"プロジェクトメンバの登録に失敗しました。 :: user_id='{user_id}'", exc_info=True)
 
         logger.info(f"{project_title} に、{count_invite_members} / {len(user_id_list)} 件のプロジェクトメンバを変更しました。")
 
-    def get_all_user_id_list_except_myself(self, project_id: str) -> List[str]:
+    def get_all_user_id_list_except_myself(self, project_id: str) -> list[str]:
         """自分自身を除いた、すべてのプロジェクトメンバを取得する"""
         member_list = self.service.wrapper.get_all_project_members(project_id)
         return [e["user_id"] for e in member_list if e["user_id"] != self.service.api.login_user_id]
 
     @staticmethod
-    def validate(args: argparse.Namespace, member_info: Optional[Dict[str, Any]] = None) -> bool:
-        COMMON_MESSAGE = "annofabcli project_member change: error:"
+    def validate(args: argparse.Namespace, member_info: Optional[dict[str, Any]] = None) -> bool:
+        COMMON_MESSAGE = "annofabcli project_member change: error:"  # noqa: N806
         if args.role is None and args.member_info is None:
-            print(f"{COMMON_MESSAGE} argument `--role`または`--member_info`のどちらかは、必ず指定してください。", file=sys.stderr)
+            print(f"{COMMON_MESSAGE} argument `--role`または`--member_info`のどちらかは、必ず指定してください。", file=sys.stderr)  # noqa: T201
             return False
 
         elif member_info is not None and not ChangeProjectMembers.validate_member_info(member_info):
-            print(f"{COMMON_MESSAGE} argument --member_info: 有効なキーが１つも指定されていません。", file=sys.stderr)
+            print(f"{COMMON_MESSAGE} argument --member_info: 有効なキーが１つも指定されていません。", file=sys.stderr)  # noqa: T201
             return False
 
         else:
             return True
 
     @staticmethod
-    def validate_member_info(member_info: Dict[str, Any]):
-        KEYS = ["sampling_inspection_rate", "sampling_acceptance_rate"]
+    def validate_member_info(member_info: dict[str, Any]) -> bool:
+        KEYS = ["sampling_inspection_rate", "sampling_acceptance_rate"]  # noqa: N806
         return any(k in member_info for k in KEYS)
 
-    def main(self):
+    def main(self) -> None:
         args = self.args
         project_id = args.project_id
         if args.all_user:
@@ -162,18 +158,16 @@ class ChangeProjectMembers(AbstractCommandLineInterface):
         if not self.validate(args, member_info):
             sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
 
-        self.change_project_members(
-            args.project_id, user_id_list=user_id_list, member_role=member_role, member_info=member_info
-        )
+        self.change_project_members(args.project_id, user_id_list=user_id_list, member_role=member_role, member_info=member_info)
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     service = build_annofabapi_resource_and_login(args)
     facade = AnnofabApiFacade(service)
     ChangeProjectMembers(service, facade, args).main()
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser) -> None:
     argument_parser = ArgumentParser(parser)
     role_choices = [e.value for e in ProjectMemberRole]
 
@@ -185,12 +179,15 @@ def parse_args(parser: argparse.ArgumentParser):
         "--user_id",
         type=str,
         nargs="+",
-        help="変更するプロジェクトメンバのuser_idを指定してください。" " ``file://`` を先頭に付けると、一覧が記載されたファイルを指定できます。",
+        help="変更するプロジェクトメンバのuser_idを指定してください。 ``file://`` を先頭に付けると、一覧が記載されたファイルを指定できます。",
     )
     user_group.add_argument("--all_user", action="store_true", help="自分以外のすべてのプロジェクトメンバを変更します。")
 
     parser.add_argument(
-        "--role", type=str, choices=role_choices, help="プロジェクトメンバにユーザに割り当てるロールを指定します。指定しない場合は、ロールは変更されません。"
+        "--role",
+        type=str,
+        choices=role_choices,
+        help="プロジェクトメンバにユーザに割り当てるロールを指定します。指定しない場合は、ロールは変更されません。",
     )
 
     parser.add_argument(
@@ -205,7 +202,7 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "change"
     subcommand_help = "プロジェクトメンバを変更します。"
     description = "複数のプロジェクトメンバに対して、メンバ情報を変更します。ただし、自分自身は変更できません。"
