@@ -2,21 +2,23 @@
 """
 日ごとユーザごとの生産性
 """
+
 from __future__ import annotations
 
 import datetime
 import logging
 from pathlib import Path
-from typing import Optional
+from typing import Any, Optional
 
 import annofabapi
 import bokeh
 import bokeh.layouts
 import bokeh.palettes
-import numpy
 import pandas
+from bokeh.models.ui import UIElement
 from bokeh.plotting import ColumnDataSource
 
+from annofabcli.common.bokeh import create_pretext_from_metadata
 from annofabcli.common.utils import print_csv
 from annofabcli.statistics.linegraph import (
     LineGraph,
@@ -25,6 +27,7 @@ from annofabcli.statistics.linegraph import (
     write_bokeh_graph,
 )
 from annofabcli.statistics.list_worktime import get_worktime_dict_from_event_list
+from annofabcli.statistics.visualization.dataframe.actual_worktime import ActualWorktime
 from annofabcli.task_history_event.list_worktime import (
     ListWorktimeFromTaskHistoryEventMain,
     WorktimeFromTaskHistoryEvent,
@@ -36,13 +39,43 @@ logger = logging.getLogger(__name__)
 class WorktimePerDate:
     """
     日ごとユーザごとの作業時間情報
+    以下の情報を持つDataFrameを格納しています。
+        * ユーザー情報
+        * 実績作業時間
+        * 計測作業時間
+    `date`,`account_id`がユニークなキーです。
     """
 
+    @classmethod
+    def required_columns_exist(cls, df: pandas.DataFrame) -> bool:
+        """
+        必須の列が存在するかどうかを返します。
+
+        Returns:
+            必須の列が存在するかどうか
+        """
+        return len(set(cls.columns) - set(df.columns)) == 0
+
+    @staticmethod
+    def _duplicated_keys(df: pandas.DataFrame) -> bool:
+        """
+        DataFrameに重複したキーがあるかどうかを返します。
+        """
+        duplicated = df.duplicated(subset=["date", "account_id"])
+        return duplicated.any()
+
     def __init__(self, df: pandas.DataFrame) -> None:
+        if not self.required_columns_exist(df):
+            raise ValueError(f"引数`df`には、{self.columns}の列が必要です。 :: {df.columns=}")
+
+        if self._duplicated_keys(df):
+            logger.warning("引数`df`に重複したキー（date, account_id）が含まれています。")
+
         self.df = df
 
-    _df_dtype = {
+    _df_dtype = {  # noqa: RUF012
         "date": "string",
+        "account_id": "string",
         "user_id": "string",
         "username": "string",
         "biography": "string",
@@ -53,6 +86,46 @@ class WorktimePerDate:
         "monitored_acceptance_worktime_hour": "float64",
     }
 
+    columns = [  # noqa: RUF012
+        "date",
+        "account_id",
+        "user_id",
+        "username",
+        "biography",
+        "actual_worktime_hour",
+        "monitored_worktime_hour",
+        "monitored_annotation_worktime_hour",
+        "monitored_inspection_worktime_hour",
+        "monitored_acceptance_worktime_hour",
+    ]
+
+    def to_non_acceptance(self) -> WorktimePerDate:
+        """
+        受入フェーズの作業時間を0にした新しいインスタンスを生成します。
+
+        `--task_completion_criteria acceptance_reached`を指定したときに利用します。
+        この場合、受入フェーズの作業時間を無視して集計する必要があるためです。
+
+        """
+        df = self.df.copy()
+        df["monitored_acceptance_worktime_hour"] = 0
+        df["monitored_worktime_hour"] = df["monitored_annotation_worktime_hour"] + df["monitored_inspection_worktime_hour"] + df["monitored_acceptance_worktime_hour"]
+        return WorktimePerDate(df)
+
+    def to_non_inspection_acceptance(self) -> WorktimePerDate:
+        """
+        検査フェーズと受入フェーズの作業時間を0にした新しいインスタンスを生成します。
+
+        `--task_completion_criteria inspection_reached`を指定したときに利用します。
+        この場合、検査フェーズと受入フェーズの作業時間を無視して集計する必要があるためです。
+
+        """
+        df = self.df.copy()
+        df["monitored_inspection_worktime_hour"] = 0
+        df["monitored_acceptance_worktime_hour"] = 0
+        df["monitored_worktime_hour"] = df["monitored_annotation_worktime_hour"]
+        return WorktimePerDate(df)
+
     def is_empty(self) -> bool:
         """
         空のデータフレームを持つかどうかを返します。
@@ -62,10 +135,6 @@ class WorktimePerDate:
         """
         return len(self.df) == 0
 
-    @property
-    def columns(self) -> list[str]:
-        return list(self._df_dtype.keys())
-
     @classmethod
     def from_csv(cls, csv_file: Path) -> WorktimePerDate:
         """CSVファイルからインスタンスを生成します。"""
@@ -83,7 +152,7 @@ class WorktimePerDate:
         cls,
         task_history_event_list: list[WorktimeFromTaskHistoryEvent],
         df_member: pandas.DataFrame,
-        df_labor: Optional[pandas.DataFrame] = None,
+        actual_worktime: ActualWorktime,
     ) -> pandas.DataFrame:
         dict_worktime = get_worktime_dict_from_event_list(task_history_event_list)
 
@@ -122,15 +191,13 @@ class WorktimePerDate:
             if f"monitored_{phase}_worktime_hour" not in df.columns:
                 df[f"monitored_{phase}_worktime_hour"] = 0
 
-        df["monitored_worktime_hour"] = (
-            df["monitored_annotation_worktime_hour"]
-            + df["monitored_inspection_worktime_hour"]
-            + df["monitored_acceptance_worktime_hour"]
-        )
+        df["monitored_worktime_hour"] = df["monitored_annotation_worktime_hour"] + df["monitored_inspection_worktime_hour"] + df["monitored_acceptance_worktime_hour"]
 
-        if df_labor is not None and len(df_labor) > 0:
+        if not actual_worktime.is_empty():
             df = df.merge(
-                df_labor[["date", "actual_worktime_hour", "account_id"]], how="outer", on=["date", "account_id"]
+                actual_worktime.df[["date", "actual_worktime_hour", "account_id"]],
+                how="outer",
+                on=["date", "account_id"],
             )
         else:
             df["actual_worktime_hour"] = 0
@@ -142,7 +209,7 @@ class WorktimePerDate:
             "monitored_inspection_worktime_hour",
             "monitored_acceptance_worktime_hour",
         ]
-        df.fillna({c: 0 for c in value_columns}, inplace=True)
+        df.fillna(dict.fromkeys(value_columns, 0), inplace=True)
 
         df = df.merge(df_member, how="left", on="account_id")
         return df[
@@ -166,17 +233,13 @@ class WorktimePerDate:
         Annoworkで作業したメンバが、Annofabのプロジェクトで作業していない場合もあるので、
         できるだけたくさんのメンバを取得できるようにするため、組織メンバを取得しています。
         """
-        project_member_list = service.wrapper.get_all_project_members(
-            project_id, query_params={"include_inactive_member": ""}
-        )
+        project_member_list = service.wrapper.get_all_project_members(project_id, query_params={"include_inactive_member": ""})
         df_project_member = pandas.DataFrame(project_member_list)
         organization, _ = service.api.get_organization_of_project(project_id)
         organization_member_list = service.wrapper.get_all_organization_members(organization["organization_name"])
         df_organization_member = pandas.DataFrame(organization_member_list)
 
-        df_member = pandas.concat([df_project_member, df_organization_member])[
-            ["account_id", "user_id", "username", "biography"]
-        ]
+        df_member = pandas.concat([df_project_member, df_organization_member])[["account_id", "user_id", "username", "biography"]]
         df_member.drop_duplicates(subset=["account_id", "user_id", "username", "biography"], inplace=True)
         return df_member
 
@@ -185,7 +248,9 @@ class WorktimePerDate:
         cls,
         service: annofabapi.Resource,
         project_id: str,
-        df_labor: Optional[pandas.DataFrame] = None,
+        actual_worktime: ActualWorktime,
+        *,
+        task_history_event_json: Optional[Path] = None,
         start_date: Optional[str] = None,
         end_date: Optional[str] = None,
     ) -> WorktimePerDate:
@@ -194,7 +259,7 @@ class WorktimePerDate:
         Args:
             service (annofabapi.Resource): [description]
             project_id (str): [description]
-            df_labor: 実績作業時間が格納されたDataFrame。date, account_id, actual_worktime_hour 列を参照する。
+            actual_worktime: 実績作業時間が格納されたDataFrameをラップしたクラス
             start_date: 指定した日以降で絞り込みます
             end_date: 指定した日以前で絞り込みます
 
@@ -203,13 +268,10 @@ class WorktimePerDate:
         """
 
         main_obj = ListWorktimeFromTaskHistoryEventMain(service, project_id=project_id)
-        worktime_list = main_obj.get_worktime_list(
-            project_id,
-        )
-
+        worktime_list = main_obj.get_worktime_list(project_id, task_history_event_json=task_history_event_json)
         df_member = cls._get_df_member(service, project_id)
 
-        df = cls.get_df_worktime(worktime_list, df_member, df_labor=df_labor)
+        df = cls.get_df_worktime(worktime_list, df_member, actual_worktime=actual_worktime)
         if start_date is not None:
             df = df[df["date"] >= start_date]
         if end_date is not None:
@@ -228,15 +290,9 @@ class WorktimePerDate:
         # 作業時間の累積値
         df_result["cumulative_actual_worktime_hour"] = groupby_obj["actual_worktime_hour"].cumsum()
         df_result["cumulative_monitored_worktime_hour"] = groupby_obj["monitored_worktime_hour"].cumsum()
-        df_result["cumulative_monitored_annotation_worktime_hour"] = groupby_obj[
-            "monitored_annotation_worktime_hour"
-        ].cumsum()
-        df_result["cumulative_monitored_acceptance_worktime_hour"] = groupby_obj[
-            "monitored_acceptance_worktime_hour"
-        ].cumsum()
-        df_result["cumulative_monitored_inspection_worktime_hour"] = groupby_obj[
-            "monitored_inspection_worktime_hour"
-        ].cumsum()
+        df_result["cumulative_monitored_annotation_worktime_hour"] = groupby_obj["monitored_annotation_worktime_hour"].cumsum()
+        df_result["cumulative_monitored_acceptance_worktime_hour"] = groupby_obj["monitored_acceptance_worktime_hour"].cumsum()
+        df_result["cumulative_monitored_inspection_worktime_hour"] = groupby_obj["monitored_inspection_worktime_hour"].cumsum()
 
         return df_result
 
@@ -244,7 +300,7 @@ class WorktimePerDate:
     def merge(cls, obj1: WorktimePerDate, obj2: WorktimePerDate) -> WorktimePerDate:
         df_tmp = pandas.concat([obj1.df, obj2.df])
 
-        df = df_tmp.groupby(["date", "user_id"])[
+        df = df_tmp.groupby(["date", "account_id"])[
             [
                 "actual_worktime_hour",
                 "monitored_worktime_hour",
@@ -255,9 +311,9 @@ class WorktimePerDate:
         ].sum()
         df.reset_index(inplace=True)
 
-        df_user = df_tmp.drop_duplicates(subset="user_id")[["user_id", "username", "biography"]]
+        df_user = df_tmp.drop_duplicates(subset="account_id")[["account_id", "user_id", "username", "biography"]]
 
-        df = df.merge(df_user, on="user_id", how="left")
+        df = df.merge(df_user, on="account_id", how="left")
 
         return cls(df)
 
@@ -269,7 +325,7 @@ class WorktimePerDate:
         return True
 
     def _get_default_user_id_list(self) -> list[str]:
-        return list(self.df.sort_values(by="date", ascending=False)["user_id"].dropna().unique())
+        return list(self.df.sort_values(by="user_id", ascending=False)["user_id"].dropna().unique())
 
     def _get_continuous_date_dataframe(self) -> pandas.DataFrame:
         """
@@ -314,8 +370,10 @@ class WorktimePerDate:
     def plot_cumulatively(
         self,
         output_file: Path,
+        *,
         target_user_id_list: Optional[list[str]] = None,
-    ):
+        metadata: Optional[dict[str, Any]] = None,
+    ) -> None:
         """
         作業時間の累積値をプロットする。
         """
@@ -349,35 +407,35 @@ class WorktimePerDate:
         line_graph_list = [
             LineGraph(
                 title="実績作業時間の累積値",
-                y_axis_label="作業時間[hour]",
+                y_axis_label="作業時間[時間]",
                 tooltip_columns=tooltip_columns,
                 x_axis_label=x_axis_label,
                 x_axis_type="datetime",
             ),
             LineGraph(
                 title="計測作業時間の累積値",
-                y_axis_label="作業時間[hour]",
+                y_axis_label="作業時間[時間]",
                 tooltip_columns=tooltip_columns,
                 x_axis_label=x_axis_label,
                 x_axis_type="datetime",
             ),
             LineGraph(
                 title="計測作業時間(教師付)の累積値",
-                y_axis_label="作業時間[hour]",
+                y_axis_label="作業時間[時間]",
                 tooltip_columns=tooltip_columns,
                 x_axis_label=x_axis_label,
                 x_axis_type="datetime",
             ),
             LineGraph(
                 title="計測作業時間(検査)の累積値",
-                y_axis_label="作業時間[hour]",
+                y_axis_label="作業時間[時間]",
                 tooltip_columns=tooltip_columns,
                 x_axis_label=x_axis_label,
                 x_axis_type="datetime",
             ),
             LineGraph(
                 title="計測作業時間(受入)の累積値",
-                y_axis_label="作業時間[hour]",
+                y_axis_label="作業時間[時間]",
                 tooltip_columns=tooltip_columns,
                 x_axis_label=x_axis_label,
                 x_axis_type="datetime",
@@ -397,16 +455,8 @@ class WorktimePerDate:
         df_cumulative = self._get_cumulative_dataframe(df_continuous_date)
         df_cumulative["dt_date"] = df_cumulative["date"].map(lambda e: datetime.datetime.fromisoformat(e).date())
 
-        # bokeh3.0.3では、string型の列を持つpandas.DataFrameを描画できないため、改めてobject型に戻す
-        # またpandas.NAを持つDataFrameも描画できないので、numpy.nanに変換する
-        # TODO この問題が解決されたら、削除する
-        # https://qiita.com/yuji38kwmt/items/b5da6ed521e827620186
-        df_cumulative = df_cumulative.astype(
-            {"date": "object", "user_id": "object", "username": "object", "biography": "object"}
-        )
-        df_cumulative.replace(pandas.NA, numpy.nan, inplace=True)
-
         line_count = 0
+        plotted_users: list[tuple[str, str]] = []
         for user_index, user_id in enumerate(user_id_list):
             df_subset = df_cumulative[df_cumulative["user_id"] == user_id]
             if df_subset.empty:
@@ -427,21 +477,27 @@ class WorktimePerDate:
                     color=color,
                 )
 
-        graph_group_list = []
+            plotted_users.append((user_id, username))
+
+        graph_group_list: list[UIElement] = []
         for line_graph in line_graph_list:
             line_graph.process_after_adding_glyphs()
             hide_all_button = line_graph.create_button_hiding_showing_all_lines(is_hiding=True)
             show_all_button = line_graph.create_button_hiding_showing_all_lines(is_hiding=False)
             checkbox_group = line_graph.create_checkbox_displaying_markers()
+            multi_choice_widget = line_graph.create_multi_choice_widget_for_searching_user(plotted_users)
 
-            widgets = bokeh.layouts.column([hide_all_button, show_all_button, checkbox_group])  # type: ignore[list-item] # noqa: E501
-            graph_group = bokeh.layouts.row([line_graph.figure, widgets])  # type: ignore[list-item]
+            widgets = bokeh.layouts.column([hide_all_button, show_all_button, checkbox_group, multi_choice_widget])
+            graph_group = bokeh.layouts.row([line_graph.figure, widgets])
             graph_group_list.append(graph_group)
 
         if line_count == 0:
             logger.warning(f"プロットするデータがなかっため、'{output_file}'は出力しません。")
             return
 
+        if metadata is not None:
+            graph_group_list.insert(0, create_pretext_from_metadata(metadata))
+
         write_bokeh_graph(bokeh.layouts.layout(graph_group_list), output_file)
 
     def to_csv(self, output_file: Path) -> None:
@@ -451,3 +507,29 @@ class WorktimePerDate:
         columns = self._df_dtype.keys()
 
         print_csv(self.df[columns], output=str(output_file))
+
+    def mask_user_info(
+        self,
+        to_replace_for_user_id: Optional[dict[str, str]] = None,
+        to_replace_for_username: Optional[dict[str, str]] = None,
+        to_replace_for_account_id: Optional[dict[str, str]] = None,
+        to_replace_for_biography: Optional[dict[str, str]] = None,
+    ) -> WorktimePerDate:
+        """
+        引数から渡された情報を元に、インスタンス変数`df`内のユーザー情報をマスクして、新しいインスタンスを返します。
+
+        Args:
+            to_replace_for_user_id: user_idを置換するためのdict。keyは置換前のuser_id, valueは置換後のuser_id。
+            to_replace_for_username: usernameを置換するためのdict。keyは置換前のusername, valueは置換後のusername。
+            to_replace_for_account_id: account_idを置換するためのdict。keyは置換前のaccount_id, valueは置換後のaccount_id。
+            to_replace_for_biography: biographyを置換するためのdict。keyは置換前のbiography, valueは置換後のbiography。
+
+        """
+        to_replace_info = {
+            "user_id": to_replace_for_user_id,
+            "username": to_replace_for_username,
+            "account_id": to_replace_for_account_id,
+            "biography": to_replace_for_biography,
+        }
+        df = self.df.replace(to_replace_info)
+        return WorktimePerDate(df)
