@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import argparse
 import logging
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional
 
 import annofabapi
 from annofabapi.dataclass.task import Task
@@ -10,9 +10,9 @@ from annofabapi.models import ProjectMemberRole, TaskStatus
 
 import annofabcli
 from annofabcli.common.cli import (
-    AbstractCommandLineInterface,
-    AbstractCommandLineWithConfirmInterface,
     ArgumentParser,
+    CommandLine,
+    CommandLineWithConfirm,
     build_annofabapi_resource_and_login,
 )
 from annofabcli.common.facade import AnnofabApiFacade, TaskQuery, match_task_with_query
@@ -21,7 +21,7 @@ from annofabcli.common.utils import add_dryrun_prefix
 logger = logging.getLogger(__name__)
 
 
-class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
+class DeleteTaskMain(CommandLineWithConfirm):
     def __init__(
         self,
         service: annofabapi.Resource,
@@ -39,25 +39,21 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
         self.force = force
         self.should_delete_input_data = should_delete_input_data
 
-        AbstractCommandLineWithConfirmInterface.__init__(self, all_yes)
+        CommandLineWithConfirm.__init__(self, all_yes)
 
     def delete_supplementary_data_list(self, task_id: str, input_data_id: str) -> int:
         supplementary_data_list, _ = self.service.api.get_supplementary_data_list(self.project_id, input_data_id)
         if len(supplementary_data_list) == 0:
             return 0
 
-        logger.debug(
-            f"task_id='{task_id}', input_data_id='{input_data_id}' :: 補助情報 {len(supplementary_data_list)} 件を削除します。"
-        )
+        logger.debug(f"task_id='{task_id}', input_data_id='{input_data_id}' :: 補助情報 {len(supplementary_data_list)} 件を削除します。")
 
         deleted_count = 0
         for supplementary_data in supplementary_data_list:
             supplementary_data_id = supplementary_data["supplementary_data_id"]
             try:
                 if not self.dryrun:
-                    self.service.api.delete_supplementary_data(
-                        self.project_id, input_data_id=input_data_id, supplementary_data_id=supplementary_data_id
-                    )
+                    self.service.api.delete_supplementary_data(self.project_id, input_data_id=input_data_id, supplementary_data_id=supplementary_data_id)
                 logger.debug(
                     f"task_id='{task_id}', input_data_id='{input_data_id}' :: 補助情報を削除しました。 :: "
                     f"supplementary_data_id='{supplementary_data_id}', "
@@ -73,19 +69,12 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
                 )
                 continue
 
-        logger.debug(
-            f"task_id='{task_id}', input_data_id='{input_data_id}' :: "
-            f"補助情報 {deleted_count} / {len(supplementary_data_list)} 件を削除しました。"
-        )
+        logger.debug(f"task_id='{task_id}', input_data_id='{input_data_id}' :: 補助情報 {deleted_count} / {len(supplementary_data_list)} 件を削除しました。")
 
         return deleted_count
 
     def confirm_deleting_input_data(self, task_id: str, input_data_id: str, input_data_name: str) -> bool:
-        message_for_confirm = (
-            f"task_id='{task_id}'のタスクから参照されている入力データと補助情報を削除しますか？  :: "
-            f"input_data_id='{input_data_id}', "
-            f"input_data_name='{input_data_name}'"
-        )
+        message_for_confirm = f"task_id='{task_id}'のタスクから参照されている入力データと補助情報を削除しますか？  :: input_data_id='{input_data_id}', input_data_name='{input_data_name}'"
         return self.confirm_processing(message_for_confirm)
 
     def delete_input_data_and_supplementary_data(self, task_id: str, input_data_id: str) -> bool:
@@ -101,10 +90,7 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
         other_task_list = [e for e in task_list if e["task_id"] != task_id and input_data_id in e["input_data_id_list"]]
         if len(other_task_list) > 0:
             other_task_id_list = [e["task_id"] for e in other_task_list]
-            logger.info(
-                f"task_id='{task_id}' :: input_data_id='{input_data_id}'の入力データは、"
-                f"他のタスクから参照されているため、削除しません。 :: 参照しているタスク = {other_task_id_list}"
-            )
+            logger.info(f"task_id='{task_id}' :: input_data_id='{input_data_id}'の入力データは、他のタスクから参照されているため、削除しません。 :: 参照しているタスク = {other_task_id_list}")
             return False
 
         input_data, _ = self.service.api.get_input_data(self.project_id, input_data_id)
@@ -117,10 +103,7 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
         # 入力データに紐づく補助情報を削除
         if not self.dryrun:
             self.service.api.delete_input_data(self.project_id, input_data_id)
-        logger.debug(
-            f"task_id='{task_id}' :: 入力データを削除しました。 :: "
-            f"input_data_id='{input_data_id}', input_data_name='{input_data['input_data_name']}'"
-        )
+        logger.debug(f"task_id='{task_id}' :: 入力データを削除しました。 :: input_data_id='{input_data_id}', input_data_name='{input_data['input_data_name']}'")
         return True
 
     def _should_delete_task(
@@ -140,26 +123,21 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
 
         annotation_list = self.get_annotation_list(task_id)
         logger.debug(f"{log_prefix} :: アノテーションが{len(annotation_list)}個付与されています。")
-        if not self.force:
+        if not self.force:  # noqa: SIM102
             if len(annotation_list) > 0:
-                logger.info(
-                    f"{log_prefix} :: アノテーションが付与されているため（{len(annotation_list)}個）、タスクの削除をスキップします。"
-                    f"削除するには`--force`を指定してください。"
-                )
+                logger.info(f"{log_prefix} :: アノテーションが付与されているため（{len(annotation_list)}個）、タスクの削除をスキップします。削除するには`--force`を指定してください。")
                 return False
 
         if not match_task_with_query(Task.from_dict(task), task_query):
             logger.debug(f"{log_prefix} :: `--task_query`の条件にマッチしないため、スキップします。task_query={task_query}")
             return False
 
-        if not self.confirm_delete_task(task_id):
+        if not self.confirm_delete_task(task_id):  # noqa: SIM103
             return False
 
         return True
 
-    def delete_task(
-        self, task_id: str, task_query: Optional[TaskQuery] = None, task_index: Optional[int] = None
-    ) -> bool:
+    def delete_task(self, task_id: str, task_query: Optional[TaskQuery] = None, task_index: Optional[int] = None) -> bool:
         """
         タスクを削除します。
 
@@ -177,7 +155,7 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
 
         """
         if task_index is not None:
-            log_prefix = f"{task_index+1} 件目, task_id='{task_id}'"
+            log_prefix = f"{task_index + 1} 件目, task_id='{task_id}'"
         else:
             log_prefix = f"task_id='{task_id}'"
 
@@ -186,10 +164,7 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
             logger.warning(f"{log_prefix} :: タスクは存在しません。")
             return False
 
-        logger.debug(
-            f"{log_prefix} :: status={task['status']}, "
-            f"phase={task['phase']}, updated_datetime={task['updated_datetime']}"
-        )
+        logger.debug(f"{log_prefix} :: status={task['status']}, phase={task['phase']}, updated_datetime={task['updated_datetime']}")
 
         if not self._should_delete_task(task, log_prefix, task_query=task_query):
             return False
@@ -206,9 +181,7 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
                     if result:
                         deleted_input_data_count += 1
                 except Exception:  # pylint: disable=broad-except
-                    logger.warning(
-                        f"{log_prefix} :: 入力データの削除に失敗しました。 :: input_data_id='{input_data_id}'", exc_info=True
-                    )
+                    logger.warning(f"{log_prefix} :: 入力データの削除に失敗しました。 :: input_data_id='{input_data_id}'", exc_info=True)
                 continue
             if deleted_input_data_count > 0:
                 logger.debug(f"{log_prefix} :: {deleted_input_data_count} 件の入力データを削除しました。")
@@ -219,14 +192,14 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
         message_for_confirm = f"タスク'{task_id}' を削除しますか？"
         return self.confirm_processing(message_for_confirm)
 
-    def get_annotation_list(self, task_id: str) -> List[Dict[str, Any]]:
+    def get_annotation_list(self, task_id: str) -> list[dict[str, Any]]:
         query_params = {"query": {"task_id": task_id, "exact_match_task_id": True}}
         annotation_list = self.service.wrapper.get_all_annotation_list(self.project_id, query_params=query_params)
         return annotation_list
 
-    def delete_task_list(
+    def delete_task_list(  # noqa: ANN201
         self,
-        task_id_list: List[str],
+        task_id_list: list[str],
         task_query: Optional[TaskQuery] = None,
     ):
         """
@@ -251,7 +224,7 @@ class DeleteTaskMain(AbstractCommandLineWithConfirmInterface):
         logger.info(f"{count_delete_task} / {len(task_id_list)} 件のタスクを削除しました。")
 
 
-class DeleteTask(AbstractCommandLineInterface):
+class DeleteTask(CommandLine):
     """
     タスクを削除する
     """
