@@ -6,7 +6,7 @@ import logging
 from collections import defaultdict
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Any, List, Optional
+from typing import Any, Optional
 
 import annofabapi
 import pandas
@@ -16,8 +16,8 @@ from dateutil.parser import parse
 
 import annofabcli
 from annofabcli.common.cli import (
-    AbstractCommandLineInterface,
     ArgumentParser,
+    CommandLine,
     build_annofabapi_resource_and_login,
     get_list_from_args,
 )
@@ -36,6 +36,20 @@ class SimpleTaskHistoryEvent(DataClassJsonMixin):
     status: str
 
 
+@dataclass
+class RequestOfTaskHistoryEvent(DataClassJsonMixin):
+    """operateTask APIによってタスク履歴イベントが生成されたときのリクエストボディ
+
+    ただし、CLIユーザーにとって不要な情報は除いています。
+    """
+
+    status: str
+    force: bool
+    account_id: Optional[str]
+    user_id: Optional[str]
+    username: Optional[str]
+
+
 @dataclass
 class WorktimeFromTaskHistoryEvent(DataClassJsonMixin):
     project_id: str
@@ -48,31 +62,29 @@ class WorktimeFromTaskHistoryEvent(DataClassJsonMixin):
     worktime_hour: float
     start_event: SimpleTaskHistoryEvent
     end_event: SimpleTaskHistoryEvent
+    end_event_request: RequestOfTaskHistoryEvent
+    """operateTask APIによってタスク履歴イベントが生成されたときのリクエストボディ"""
 
 
 class ListWorktimeFromTaskHistoryEventMain:
-    def __init__(self, service: annofabapi.Resource, *, project_id: str):
+    def __init__(self, service: annofabapi.Resource, *, project_id: str) -> None:
         self.service = service
         self.visualize = AddProps(service, project_id)
 
     @staticmethod
-    def filter_task_history_event(
-        task_history_event_list: list[TaskHistoryEvent], task_id_list: Optional[list[str]] = None
-    ) -> list[TaskHistoryEvent]:
+    def filter_task_history_event(task_history_event_list: list[TaskHistoryEvent], task_id_list: Optional[list[str]] = None) -> list[TaskHistoryEvent]:
         if task_id_list is not None:
             result = []
             task_id_set = set(task_id_list)
             for event in task_history_event_list:
                 if event["task_id"] in task_id_set:
-                    result.append(event)
+                    result.append(event)  # noqa: PERF401
 
             return result
 
         return task_history_event_list
 
-    def get_task_history_event_list(
-        self, project_id: str, task_history_event_json: Optional[Path] = None
-    ) -> list[dict[str, Any]]:
+    def get_task_history_event_list(self, project_id: str, task_history_event_json: Optional[Path] = None) -> list[dict[str, Any]]:
         if task_history_event_json is None:
             downloading_obj = DownloadingFile(self.service)
             cache_dir = annofabcli.common.utils.get_cache_dir()
@@ -114,16 +126,10 @@ class ListWorktimeFromTaskHistoryEventMain:
 
         return result
 
-    def _create_worktime(
-        self, start_event: TaskHistoryEvent, end_event: TaskHistoryEvent
-    ) -> WorktimeFromTaskHistoryEvent:
+    def _create_worktime(self, start_event: TaskHistoryEvent, end_event: TaskHistoryEvent) -> WorktimeFromTaskHistoryEvent:
         diff = parse(end_event["created_datetime"]) - parse(start_event["created_datetime"])
         worktime_hour = diff.total_seconds() / 3600
-        assert worktime_hour >= 0, (
-            f"worktime_hourが負の値です。"
-            f"start_event.created_datetime={start_event['created_datetime']}, "
-            f"end_event.created_datetime{end_event['created_datetime']}"
-        )
+        assert worktime_hour >= 0, f"worktime_hourが負の値です。start_event.created_datetime={start_event['created_datetime']}, end_event.created_datetime{end_event['created_datetime']}"
 
         member = self.visualize.get_project_member_from_account_id(start_event["account_id"])
         if member is not None:
@@ -133,6 +139,15 @@ class ListWorktimeFromTaskHistoryEventMain:
             user_id = None
             username = None
 
+        end_event_request_account_id = end_event["request"]["account_id"]
+        end_event_request_member = self.visualize.get_project_member_from_account_id(end_event_request_account_id)
+        if end_event_request_member is not None:
+            end_event_request_user_id = end_event_request_member["user_id"]
+            end_event_request_username = end_event_request_member["username"]
+        else:
+            end_event_request_user_id = None
+            end_event_request_username = None
+
         return WorktimeFromTaskHistoryEvent(
             # start_eventとend_eventの以下の属性は同じなので、start_eventの値を参照する
             project_id=start_event["project_id"],
@@ -153,11 +168,16 @@ class ListWorktimeFromTaskHistoryEventMain:
                 created_datetime=end_event["created_datetime"],
                 status=end_event["status"],
             ),
+            end_event_request=RequestOfTaskHistoryEvent(
+                status=end_event["request"]["status"],
+                force=end_event["request"]["force"],
+                account_id=end_event["request"]["account_id"],
+                user_id=end_event_request_user_id,
+                username=end_event_request_username,
+            ),
         )
 
-    def _create_worktime_list(
-        self, task_history_event_list: list[TaskHistoryEvent]
-    ) -> list[WorktimeFromTaskHistoryEvent]:
+    def _create_worktime_list(self, task_id: str, task_history_event_list: list[TaskHistoryEvent]) -> list[WorktimeFromTaskHistoryEvent]:
         """タスク履歴イベントから、作業時間のリストを生成する。
 
         Args:
@@ -187,7 +207,10 @@ class ListWorktimeFromTaskHistoryEventMain:
                 TaskStatus.COMPLETE.value,
             }:
                 logger.warning(
-                    "作業中状態のタスク履歴イベントに対応するタスク履歴イベントが存在しませんでした。" f":: start_event={start_event}, next_event={next_event}"
+                    f"task_id='{task_id}' :: 作業開始のイベント（task_history_id='{event['task_history_id']}'）の次のイベント（task_history_id='{next_event['task_history_id']}'）は、"
+                    f"作業終了のイベントではないため、作業時間を算出できません。スキップします。"
+                    f"タスク履歴イベントが不整合な状態なので、Annofabチームに問い合わせてください。 :: "
+                    f"start_event='{start_event}', next_event='{next_event}'"
                 )
                 i += 1
                 continue
@@ -200,39 +223,31 @@ class ListWorktimeFromTaskHistoryEventMain:
         return result
 
     def get_account_ids_from_user_ids(self, project_id: str, user_ids: set[str]) -> set[str]:
-        project_member_list = self.service.wrapper.get_all_project_members(
-            project_id, query_params={"include_inactive_member": True}
-        )
+        project_member_list = self.service.wrapper.get_all_project_members(project_id, query_params={"include_inactive_member": True})
         return {e["account_id"] for e in project_member_list if e["user_id"] in user_ids}
 
     def get_worktime_list(
         self,
         project_id: str,
         task_history_event_json: Optional[Path] = None,
-        task_id_list: Optional[List[str]] = None,
-        user_id_list: Optional[List[str]] = None,
+        task_id_list: Optional[list[str]] = None,
+        user_id_list: Optional[list[str]] = None,
     ) -> list[WorktimeFromTaskHistoryEvent]:
-        all_task_history_event_list = self.get_task_history_event_list(
-            project_id, task_history_event_json=task_history_event_json
-        )
+        all_task_history_event_list = self.get_task_history_event_list(project_id, task_history_event_json=task_history_event_json)
 
         task_id_set = set(task_id_list) if task_id_list is not None else None
-        account_id_set = (
-            self.get_account_ids_from_user_ids(project_id, set(user_id_list)) if user_id_list is not None else None
-        )
+        account_id_set = self.get_account_ids_from_user_ids(project_id, set(user_id_list)) if user_id_list is not None else None
 
-        task_history_event_dict = self._create_task_history_event_dict(
-            all_task_history_event_list, task_ids=task_id_set, account_ids=account_id_set
-        )
+        task_history_event_dict = self._create_task_history_event_dict(all_task_history_event_list, task_ids=task_id_set, account_ids=account_id_set)
 
         worktime_list = []
-        for subset_event_list in task_history_event_dict.values():
-            subset_worktime_list = self._create_worktime_list(subset_event_list)
+        for task_id, subset_event_list in task_history_event_dict.items():
+            subset_worktime_list = self._create_worktime_list(task_id, subset_event_list)
             worktime_list.extend(subset_worktime_list)
         return worktime_list
 
 
-class ListWorktimeFromTaskHistoryEvent(AbstractCommandLineInterface):
+class ListWorktimeFromTaskHistoryEvent(CommandLine):
     def print_worktime_from_task_history_event(
         self,
         project_id: str,
@@ -240,7 +255,7 @@ class ListWorktimeFromTaskHistoryEvent(AbstractCommandLineInterface):
         task_id_list: Optional[list[str]],
         user_id_list: Optional[list[str]],
         arg_format: FormatArgument,
-    ):
+    ) -> None:
         super().validate_project(project_id, project_member_roles=None)
 
         main_obj = ListWorktimeFromTaskHistoryEventMain(self.service, project_id=project_id)
@@ -252,19 +267,40 @@ class ListWorktimeFromTaskHistoryEvent(AbstractCommandLineInterface):
         )
 
         logger.debug(f"作業時間一覧の件数: {len(worktime_list)}")
+        dict_worktime_list = [e.to_dict() for e in worktime_list]
 
-        if len(worktime_list) > 0:
-            dict_worktime_list = [e.to_dict() for e in worktime_list]
-            if arg_format == FormatArgument.CSV:
-                df = pandas.json_normalize(dict_worktime_list)
-                self.print_csv(df)
+        if arg_format == FormatArgument.CSV:
+            columns = [
+                "project_id",
+                "task_id",
+                "phase",
+                "phase_stage",
+                "account_id",
+                "user_id",
+                "username",
+                "worktime_hour",
+                "start_event.task_history_id",
+                "start_event.created_datetime",
+                "start_event.status",
+                "end_event.task_history_id",
+                "end_event.created_datetime",
+                "end_event.status",
+                "end_event_request.status",
+                "end_event_request.force",
+                "end_event_request.account_id",
+                "end_event_request.user_id",
+                "end_event_request.username",
+            ]
+
+            if len(dict_worktime_list) > 0:
+                df = pandas.json_normalize(dict_worktime_list)[columns]
             else:
-                self.print_according_to_format(dict_worktime_list)
+                df = pandas.DataFrame(columns=columns)
+            self.print_csv(df)
         else:
-            logger.warning("作業時間一覧の件数が0件であるため、出力しません。")
-            return
+            self.print_according_to_format(dict_worktime_list)
 
-    def main(self):
+    def main(self) -> None:
         args = self.args
 
         task_id_list = get_list_from_args(args.task_id) if args.task_id is not None else None
@@ -279,22 +315,20 @@ class ListWorktimeFromTaskHistoryEvent(AbstractCommandLineInterface):
         )
 
     @staticmethod
-    def to_all_task_history_event_list_from_dict(
-        task_history_event_dict: dict[str, list[dict[str, Any]]]
-    ) -> List[dict[str, Any]]:
+    def to_all_task_history_event_list_from_dict(task_history_event_dict: dict[str, list[dict[str, Any]]]) -> list[dict[str, Any]]:
         all_task_history_event_list = []
         for task_history_event_list in task_history_event_dict.values():
             all_task_history_event_list.extend(task_history_event_list)
         return all_task_history_event_list
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     service = build_annofabapi_resource_and_login(args)
     facade = AnnofabApiFacade(service)
     ListWorktimeFromTaskHistoryEvent(service, facade, args).main()
 
 
-def parse_args(parser: argparse.ArgumentParser):
+def parse_args(parser: argparse.ArgumentParser) -> None:
     argument_parser = ArgumentParser(parser)
 
     argument_parser.add_project_id()
@@ -304,7 +338,7 @@ def parse_args(parser: argparse.ArgumentParser):
         "--task_id",
         type=str,
         nargs="+",
-        help="対象のタスクのuser_idを指定します。\n" "``file://`` を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。",
+        help="対象のタスクのuser_idを指定します。\n``file://`` を先頭に付けると、task_idの一覧が記載されたファイルを指定できます。",
     )
 
     parser.add_argument(
@@ -312,7 +346,7 @@ def parse_args(parser: argparse.ArgumentParser):
         "--user_id",
         type=str,
         nargs="+",
-        help="絞り込み対象のユーザのuser_idを指定します。\n" "``file://`` を先頭に付けると、user_idの一覧が記載されたファイルを指定できます。",
+        help="絞り込み対象のユーザのuser_idを指定します。\n``file://`` を先頭に付けると、user_idの一覧が記載されたファイルを指定できます。",
     )
 
     parser.add_argument(
@@ -328,12 +362,11 @@ def parse_args(parser: argparse.ArgumentParser):
         default=FormatArgument.CSV,
     )
     argument_parser.add_output()
-    argument_parser.add_csv_format()
 
     parser.set_defaults(subcommand_func=main)
 
 
-def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None) -> argparse.ArgumentParser:
     subcommand_name = "list_worktime"
     subcommand_help = "タスク履歴イベントから作業時間の一覧を出力します。"
     description = "タスク履歴イベントから作業時間の一覧を出力します。\nタスク履歴より詳細な作業時間の情報を出力します。"
